#include "MainWindow.h"
#include "GLWindow.h"
#include <ngl/NGLInit.h>

//----------------------------------------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------------------------------------
MainWindow::MainWindow(
                       QWidget *_parent
                      ):
                        QMainWindow(_parent)
{
	// first we re-size the window to the size we need
	this->resize(QSize(1024,720));
	// now create our GL window and parent it to this
	m_gl = new GLWindow(this);
	// this is the window title
	this->setWindowTitle(QString("Use Arrow keys and R to move ship F/N toggles fullscreen / normal"));
}

//----------------------------------------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------------------------------------
MainWindow::~MainWindow()
{
	// no need to do anything at present
}


//----------------------------------------------------------------------------------------------------------------------
void MainWindow::keyReleaseEvent(
																	QKeyEvent *_event
																 )
{
	// once we have processed any key here pass the event
	// onto the GLWindow class to do more processing
  m_gl->processKeyUp(_event);

}
//----------------------------------------------------------------------------------------------------------------------
void MainWindow::keyPressEvent(
                               QKeyEvent *_event
                              )
{
  // this method is called every time the main window recives a key event.
  // we then switch on the key value and set the camera in the GLWindow
  switch (_event->key())
  {
  case Qt::Key_Escape : QApplication::exit(EXIT_SUCCESS); break;
  case Qt::Key_W : glPolygonMode(GL_FRONT_AND_BACK,GL_LINE); break;
  case Qt::Key_S : glPolygonMode(GL_FRONT_AND_BACK,GL_FILL); break;
  case Qt::Key_F : showFullScreen(); break;
  case Qt::Key_N : showNormal(); break;
  default : break;
  }
	// once we have processed any key here pass the event
	// onto the GLWindow class to do more processing
  m_gl->processKeyDown(_event);
}

//----------------------------------------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------------------------------------
void MainWindow::resizeEvent ( QResizeEvent * _event )
{
  m_gl->resize(_event->size());
}

